import raypyc


LIGHTGRAY: raypyc.structures.Color
GRAY: raypyc.structures.Color
DARKGRAY: raypyc.structures.Color
YELLOW: raypyc.structures.Color
GOLD: raypyc.structures.Color
ORANGE: raypyc.structures.Color
PINK: raypyc.structures.Color
RED: raypyc.structures.Color
MAROON: raypyc.structures.Color
GREEN: raypyc.structures.Color
LIME: raypyc.structures.Color
DARKGREEN: raypyc.structures.Color
SKYBLUE: raypyc.structures.Color
BLUE: raypyc.structures.Color
DARKBLUE: raypyc.structures.Color
PURPLE: raypyc.structures.Color
VIOLET: raypyc.structures.Color
DARKPURPLE: raypyc.structures.Color
BEIGE: raypyc.structures.Color
BROWN: raypyc.structures.Color
DARKBROWN: raypyc.structures.Color
WHITE: raypyc.structures.Color
BLACK: raypyc.structures.Color
BLANK: raypyc.structures.Color
MAGENTA: raypyc.structures.Color
RAYWHITE: raypyc.structures.Color
