import raypyc


LIGHTGRAY: raypyc.structures.Color = raypyc.structures.Color(200, 200, 200, 255)  # Light Gray
GRAY: raypyc.structures.Color = raypyc.structures.Color(130, 130, 130, 255)  # Gray
DARKGRAY: raypyc.structures.Color = raypyc.structures.Color(80, 80, 80, 255)  # Dark Gray
YELLOW: raypyc.structures.Color = raypyc.structures.Color(253, 249, 0, 255)  # Yellow
GOLD: raypyc.structures.Color = raypyc.structures.Color(255, 203, 0, 255)  # Gold
ORANGE: raypyc.structures.Color = raypyc.structures.Color(255, 161, 0, 255)  # Orange
PINK: raypyc.structures.Color = raypyc.structures.Color(255, 109, 194, 255)  # Pink
RED: raypyc.structures.Color = raypyc.structures.Color(230, 41, 55, 255)  # Red
MAROON: raypyc.structures.Color = raypyc.structures.Color(190, 33, 55, 255)  # Maroon
GREEN: raypyc.structures.Color = raypyc.structures.Color(0, 228, 48, 255)  # Green
LIME: raypyc.structures.Color = raypyc.structures.Color(0, 158, 47, 255)  # Lime
DARKGREEN: raypyc.structures.Color = raypyc.structures.Color(0, 117, 44, 255)  # Dark Green
SKYBLUE: raypyc.structures.Color = raypyc.structures.Color(102, 191, 255, 255)  # Sky Blue
BLUE: raypyc.structures.Color = raypyc.structures.Color(0, 121, 241, 255)  # Blue
DARKBLUE: raypyc.structures.Color = raypyc.structures.Color(0, 82, 172, 255)  # Dark Blue
PURPLE: raypyc.structures.Color = raypyc.structures.Color(200, 122, 255, 255)  # Purple
VIOLET: raypyc.structures.Color = raypyc.structures.Color(135, 60, 190, 255)  # Violet
DARKPURPLE: raypyc.structures.Color = raypyc.structures.Color(112, 31, 126, 255)  # Dark Purple
BEIGE: raypyc.structures.Color = raypyc.structures.Color(211, 176, 131, 255)  # Beige
BROWN: raypyc.structures.Color = raypyc.structures.Color(127, 106, 79, 255)  # Brown
DARKBROWN: raypyc.structures.Color = raypyc.structures.Color(76, 63, 47, 255)  # Dark Brown
WHITE: raypyc.structures.Color = raypyc.structures.Color(255, 255, 255, 255)  # White
BLACK: raypyc.structures.Color = raypyc.structures.Color(0, 0, 0, 255)  # Black
BLANK: raypyc.structures.Color = raypyc.structures.Color(0, 0, 0, 0)  # Blank (Transparent)
MAGENTA: raypyc.structures.Color = raypyc.structures.Color(255, 0, 255, 255)  # Magenta
RAYWHITE: raypyc.structures.Color = raypyc.structures.Color(245, 245, 245, 255)  # My own White (raylib logo)
